@@ -1,10 +1,11 @@
-from .base import Builder
-from clickable.config.project import ProjectConfig
 from clickable.config.constants import Constants
 
+from .base import Builder
+
 
 class CustomBuilder(Builder):
     name = Constants.CUSTOM
 
     def build(self):
-        self.config.container.run_command(self.config.build)
+        for cmd in self.config.build:
+            self.container.run_command(cmd)
